/*  
 * Routines to interface to the boot PROM callback functions for the various
 * models of DECSTATION's.
 *
 * Much of this file is from code found in the Mach Operating System.
 *
 * Modifications to this file (originally called asm_misc.s are
 * Copyright (C) 1995,1996,1997 by Paul M. Antoine, with some code and
 * definitions curteousy of Chris Fraser.
 *
 * Other parts of this file are therefore:
 *
 * Copyright (c) 1991,1990,1989 Carnegie Mellon University
 * All Rights Reserved.
 *
 * And as such I must quote the following copyright, that applies to those
 * portions of this file so covered:
 * 
 * Permission to use, copy, modify and distribute this software and its
 * documentation is hereby granted, provided that both the copyright
 * notice and this permission notice appear in all copies of the
 * software, derivative works or modified versions, and any portions
 * thereof, and that both notices appear in supporting documentation.
 * 
 * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
 * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Carnegie Mellon requests users of this software to return to
 * 
 *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
 *  School of Computer Science
 *  Carnegie Mellon University
 *  Pittsburgh PA 15213-3890
 * 
 * any improvements or extensions that they make and grant Carnegie Mellon
 * the rights to redistribute these changes.
 */
#include <asm/asm.h>
#include <asm/regdef.h>
#include <asm/mipsconfig.h>
#include <asm/mipsregs.h>
#include <asm/stackframe.h>

#include <asm/dec/prom.h>

	.text
	.set	reorder
/*
 *	PROM interface jump table, pmax/3max version for DS2100/3100's and
 *	DS5000/2xx's
 *
 *	Object:
 * 		pmax_halt			EXPORTED function
 * 		pmax_open			EXPORTED function
 * 		pmax_lseek			EXPORTED function
 * 		pmax_read			EXPORTED function
 * 		pmax_close			EXPORTED function
 * 		pmax_gets			EXPORTED function
 * 		pmax_printf			EXPORTED function
 * 		pmax_geten			EXPORTED function
 * 		pmax_dummy			EXPORTED function
 */
	.text

	EXPORT(pmax_halt)
	li	v0,PMAX_PROM_HALT
	j	v0

	EXPORT(pmax_open)
	li	v0,PMAX_PROM_OPEN
	j	v0

	EXPORT(pmax_lseek)
	li	v0,PMAX_PROM_LSEEK
	j	v0

	EXPORT(pmax_read)
	li	v0,PMAX_PROM_READ
	j	v0

	EXPORT(pmax_close)
	li	v0,PMAX_PROM_CLOSE
	j	v0

	EXPORT(pmax_gets)
	li	v0,PMAX_PROM_GETS
	j	v0

	EXPORT(pmax_printf)
	li	v0,PMAX_PROM_PRINTF
	j	v0

	EXPORT(pmax_getenv)
	li	v0,PMAX_PROM_GETENV
	j	v0

	EXPORT(pmax_dummy)
	li	a0,0
	j	ra

/*
 *	PROM interface jump table, 3min version for REX PROM systems such as
 *	DS5000/1xx's and DS5000/2x's
 *
 *	Object:
 * 		rex_halt				EXPORTED function
 * 		rex_open				EXPORTED function
 * 		rex_lseek				EXPORTED function
 * 		rex_read				EXPORTED function
 * 		rex_close				EXPORTED function
 * 		rex_gets				EXPORTED function
 * 		rex_printf				EXPORTED function
 * 		rex_getenv				EXPORTED function
 * 		rex_getbitmap				EXPORTED function
 * 		rex_getsysid				EXPORTED function
 */
	.text

rex_call:
	lw	t0,rex_prom_base
	addu	v0,t0
	lw	v0,0(v0)
	j	v0
	
	EXPORT(rex_halt)
	li	v0,REX_PROM_HALT
	j	rex_call

	EXPORT(rex_gets)
	li	v0,REX_PROM_GETS
	j	rex_call

	EXPORT(rex_printf)
	li	v0,REX_PROM_PRINTF
	j	rex_call

	EXPORT(rex_getenv)
	li	v0,REX_PROM_GETENV
	j	rex_call

	EXPORT(rex_open)
	li	v0,REX_PROM_OPEN
	j	rex_call

	EXPORT(rex_lseek)
	/* turn seek ptr back to blockno */
	srl	a1,9
	sw	a1,rex_seek_ptr
	j	ra

	EXPORT(rex_read)
	lw	a0,rex_seek_ptr
	li	v0,REX_PROM_READ
	j	rex_call

	EXPORT(rex_close)
	li	v0,-1
	j	ra

	EXPORT(rex_getbitmap)
	li	v0,REX_PROM_GETBITMAP
	j	rex_call

	EXPORT(rex_getsysid)
	li	v0,REX_PROM_GETSYSID
	j	rex_call

	.data
	.align 4
rex_seek_ptr:	.word	0		# current seek position
