/*  
 * Routine to determine the identity of the boot PROMs on various models of
 * DECSTATION's.
 *
 * Much of this file is from code found in the Mach Operating System.
 *
 * Modifications to this file (originally called c_misc.c are
 * Copyright (C) 1995,1996,1997 by Paul M. Antoine, with some code and
 * definitions curteousy of Chris Fraser.
 *
 * Other parts of this file are therefore:
 *
 * Copyright (c) 1991,1990,1989 Carnegie Mellon University
 * All Rights Reserved.
 *
 * And as such I must quote the following copyright, that applies to those
 * portions of this file so covered:
 * 
 * Permission to use, copy, modify and distribute this software and its
 * documentation is hereby granted, provided that both the copyright
 * notice and this permission notice appear in all copies of the
 * software, derivative works or modified versions, and any portions
 * thereof, and that both notices appear in supporting documentation.
 * 
 * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
 * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Carnegie Mellon requests users of this software to return to
 * 
 *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
 *  School of Computer Science
 *  Carnegie Mellon University
 *  Pittsburgh PA 15213-3890
 * 
 * any improvements or extensions that they make and grant Carnegie Mellon
 * the rights to redistribute these changes.
 */

#include <asm/dec/prom.h>

prom_call_t prom_call;		/* PROM callback interface */

/*
 * Detect which PROM's the DECSTATION has, and set the callback vectors
 * appropriately.
 */
void which_prom(void)
{
	extern unsigned long rex_prom_magic;

	/*
	 * No sign of the REX PROM's magic number means we assume a non-REX
	 * machine (i.e. we're on a DS2100/3100 or DS5000/2xx)
	 */
	if (rex_prom_magic == REX_PROM_MAGIC)
	{
		/*
		 * Set up prom abstraction structure with REX entry points.
		 */
		prom_call.halt = rex_halt;
		prom_call.open = rex_open;
		prom_call.lseek = rex_lseek;
		prom_call.read = rex_read;
		prom_call.close = rex_close;
		prom_call.gets = rex_gets;
		prom_call.printf = rex_printf;
		prom_call.getenv = rex_getenv;
		prom_call.getbitmap = rex_getbitmap;
		prom_call.getsysid = rex_getsysid;
		rex_printf("Found a REX compatible boot PROM!\n");
	}
	else
	{
		/*
		 * Set up prom abstraction structure with non-REX entry points.
		 */
		prom_call.halt = pmax_halt;
		prom_call.open = pmax_open;
		prom_call.lseek = pmax_lseek;
		prom_call.read = pmax_read;
		prom_call.close = pmax_close;
		prom_call.gets = pmax_gets;
		prom_call.printf = pmax_printf;
		prom_call.getenv = pmax_getenv;
		/* Dummies for REX prom routines the DS2100/3100's and
		 * DS5000/2xx's don't have!
		 */
		prom_call.getbitmap = pmax_dummy;
		prom_call.getsysid = pmax_dummy;
		pmax_printf("Found a PMAX/MIPS compatible boot PROM!\n");
	}
	return;
} /* which_prom() */
